@@ -4,6 +4,7 @@ from oauthlib import oauth1
 import json
 import os
 import re
+from discogs_client.utils import backoff
 from urllib.parse import parse_qsl
 
 
@@ -14,6 +15,8 @@ class Fetcher:
 
     (It's a slightly leaky abstraction designed to make testing easier.)
     """
+    backoff_enabled = True
+
     def fetch(self, client, method, url, data=None, headers=None, json=True):
         """Fetch the given request
 
@@ -24,6 +27,11 @@ class Fetcher:
         """
         raise NotImplementedError()
 
+    @backoff
+    def request(self, method, url, data, headers, params=None):
+        response = request(method=method, url=url, data=data, headers=headers, params=params)
+        return response
+
 
 class LoggingDelegator:
     """Wraps a fetcher and logs all requests."""
@@ -43,7 +51,7 @@ class LoggingDelegator:
 class RequestsFetcher(Fetcher):
     """Fetches via HTTP from the Discogs API."""
     def fetch(self, client, method, url, data=None, headers=None, json=True):
-        resp = requests.request(method, url, data=data, headers=headers)
+        resp = self.request(method, url, data=data, headers=headers)
         self.rate_limit = resp.headers.get(
                 'X-Discogs-Ratelimit')
         self.rate_limit_used = resp.headers.get(
@@ -60,8 +68,9 @@ class UserTokenRequestsFetcher(Fetcher):
 
     def fetch(self, client, method, url, data=None, headers=None, json_format=True):
         data = json.dumps(data) if json_format and data else data
-        resp = requests.request(method, url, params={'token':self.user_token},
-                                data=data, headers=headers)
+        resp = self.request(
+            method, url, data=data, headers=headers, params={'token':self.user_token}
+        )
         self.rate_limit = resp.headers.get(
                 'X-Discogs-Ratelimit')
         self.rate_limit_used = resp.headers.get(
@@ -99,7 +108,7 @@ class OAuth2Fetcher(Fetcher):
         uri, headers, body = self.client.sign(url, http_method=method,
                                               body=body, headers=headers)
 
-        resp = request(method, uri, headers=headers, data=body)
+        resp = self.request(method, url, data=body, headers=headers)
         self.rate_limit = resp.headers.get(
                 'X-Discogs-Ratelimit')
         self.rate_limit_used = resp.headers.get(
